@@ -25,6 +25,14 @@ def recent_windows(exclude, limit):
     return True
 
 
+@cli.command()
+@click.option('--exclude')
+def recent_window(exclude):
+    recent_window_result = gui.get_recent_window(exclude=exclude)
+    print(recent_window_result)
+    return True
+
+
 @cli.command()
 def focus_on_window():
     print('[START]')
